Enum GoodTilOneof
pub enum GoodTilOneof {
GoodTilBlock(u32),
GoodTilBlockTime(u32),
}Expand description
Information about when the order cancellation expires.
Variants
GoodTilBlock(u32)
The last block this order cancellation can be executed at. Used only for Short-Term orders and must be zero for stateful orders.
GoodTilBlockTime(u32)
good_til_block_time represents the unix timestamp (in seconds) at which a
stateful order cancellation will be considered expired. The
good_til_block_time is always evaluated against the previous block’s
BlockTime instead of the block in which the order is committed.
This value must be zero for Short-Term orders.
Implementations
impl GoodTilOneof
impl GoodTilOneof
pub fn encode(&self, buf: &mut impl BufMut)
pub fn encode(&self, buf: &mut impl BufMut)
Encodes the message to a buffer.
pub fn merge(
field: &mut Option<GoodTilOneof>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<GoodTilOneof>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
pub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.